OC.L10N.register(
    "settings",
    {
    "Private" : "Privatno",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Vidljivo samo ljudima koji se podudaraju putem integracije broja telefona u aplikaciji Talk na mobilnom uređaju",
    "Local" : "Lokalno",
    "Only visible to people on this instance and guests" : "Vidljivo samo ljudima na ovoj instanci i gostima",
    "Federated" : "Udruženo",
    "Only synchronize to trusted servers" : "Sinkroniziraj samo s pouzdanim poslužiteljima",
    "Published" : "Objavljeno",
    "Synchronize to trusted servers and the global and public address book" : "Sinkroniziraj s pouzdanim poslužiteljima i globalnim i javnim adresarom",
    "Verify" : "Provjeri",
    "Verifying …" : "Provjeravanje…",
    "Unable to change password" : "Promjena zaporke nije moguća",
    "Very weak password" : "Zaporka vrlo slaba",
    "Weak password" : "Zaporka slaba",
    "So-so password" : "Zaporka prosječne jačine",
    "Good password" : "Zaporka dobra",
    "Strong password" : "Zaporka jaka",
    "Groups" : "Grupe",
    "Group list is empty" : "Popis grupa je prazan",
    "Unable to retrieve the group list" : "Nije moguće preuzeti popis grupa",
    "{actor} added you to group {group}" : "{actor} vas je dodao u grupu {group}",
    "You added {user} to group {group}" : "Dodali ste {user} u grupu {group}",
    "{actor} added {user} to group {group}" : "{actor} je dodao {user} u grupu {grupa}",
    "An administrator added you to group {group}" : "Administrator vas je dodao u grupu {group}",
    "An administrator added {user} to group {group}" : "Administrator je dodao {user} u grupu {group}",
    "{actor} removed you from group {group}" : "{actor} vas je uklonio iz grupe {group}",
    "You removed {user} from group {group}" : "Uklonili ste {user} iz grupe {group}",
    "{actor} removed {user} from group {group}" : "{actor} je uklonio {user} iz grupe {group}",
    "An administrator removed you from group {group}" : "Administrator vas je uklonio iz grupe {group}",
    "An administrator removed {user} from group {group}" : "Administrator je uklonio {user} iz grupe {group}",
    "Your <strong>group memberships</strong> were modified" : "Vaša <strong>članstva u grupama</strong> su izmijenjena",
    "{actor} changed your password" : "{actor} je promijenio vašu zaporku",
    "You changed your password" : "Promijenili ste svoju zaporku",
    "Your password was reset by an administrator" : "Administrator je resetirao vašu zaporku",
    "Your password was reset" : "Vaša zaporka je resetirana",
    "{actor} changed your email address" : "{actor} je promijenio vašu adresu e-pošte",
    "You changed your email address" : "Promijenili ste svoju adresu e-pošte",
    "Your email address was changed by an administrator" : "Administrator je promijenio vašu adresu e-pošte",
    "You deleted app password \"{token}\"" : "Izbrisali ste zaporku aplikacije „{token}”",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Preimenovali ste zaporku aplikacije „{token}” u „{newToken}”",
    "You granted filesystem access to app password \"{token}\"" : "Odobrili ste zaporki aplikacije „{token}” pristup datotečnom sustavu",
    "You revoked filesystem access from app password \"{token}\"" : "Opozvali ste zaporki aplikacije „{token}” pristup datotečnom sustavu",
    "Security" : "Sigurnost",
    "You successfully logged in using two-factor authentication (%1$s)" : "Uspješno ste se prijavili s pomoću dvofaktorske autentifikacije (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Neuspješan pokušaj prijave s pomoću dvofaktorske autentifikacije (%1$s)",
    "Remote wipe was started on %1$s" : "Udaljeno brisanje pokrenuto je %1$s",
    "Remote wipe has finished on %1$s" : "Udaljeno brisanje završilo je %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Izmijenjena je vaša <strong>zaporka</strong> ili <strong>adresa e-pošte</strong>",
    "Apps" : "Aplikacije",
    "Wrong password" : "Pogrešna zaporka",
    "Saved" : "Spremljeno",
    "No user supplied" : "Nijedan korisnik nije podnesen",
    "Authentication error" : "Pogrešna autentifikacija",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Unesite administratorsku zaporku za oporavak; u protivnom će svi podaci korisnika biti izgubljeni.",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna administratorska zaporka za oporavak. Provjerite zaporku i pokušajte ponovno.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instaliranje i ažuriranje aplikacija putem trgovine aplikacijama ili dijeljenja putem udruženog oblaka",
    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL upotrebljava zastarjelu inačicu %1$s (%2$s). Ažurirajte svoj operacijski sustav kako bi značajke, kao što je %3$s, pouzdano radile.",
    "Administrator documentation" : "Dokumentacija za administratora",
    "User documentation" : "Dokumentacija za korisnike",
    "Invalid SMTP password." : "Nevaljana zaporka za SMTP.",
    "Email setting test" : "Testiranje postavljanja e-pošte",
    "Well done, %s!" : "Odlično, %s!",
    "If you received this email, the email configuration seems to be correct." : "Ako ste primili ovu poruku e-pošte, čini se da je e-pošta pravilno konfigurirana.",
    "Email could not be sent. Check your mail server log" : "Slanje poruke e-pošte nije uspjelo. Provjerite zapis poslužitelja e-pošte",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Došlo je do problema pri slanju poruke e-pošte. Pregledajte svoje postavke. (Pogreška: %s)",
    "Users" : "Korisnici",
    "Invalid user" : "Nevažeći korisnik",
    "Invalid mail address" : "Nevažeća adresa e-pošte",
    "Settings saved" : "Postavke spremljene",
    "Unable to change full name" : "Nije moguće promijeniti puno ime",
    "Unable to change email address" : "Nije moguće promijeniti adresu e-pošte",
    "Unable to set invalid phone number" : "Postavljanje nevažećeg telefonskog broja nije uspjelo",
    "Unable to set invalid website" : "Nije moguće postaviti nevažeće web-mjesto",
    "Some account data was invalid" : "Određeni podaci o računu nisu važeći",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Kako biste potvrdili svoj Twitter račun, objavite sljedeću poruku na Twitteru (objavite bez ikakvih prekida retka):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Kako biste potvrdili svoje web-mjesto, pohranite sljedeći sadržaj u korijensku mapu na ‘.well-known/CloudIdVerificationCode.txt’ (cijeli tekst treba biti u jednom retku):",
    "%1$s changed your password on %2$s." : "%1$s je promijenio vašu zaporku na %2$s.",
    "Your password on %s was changed." : "Promijenjena je vaša zaporka na %s.",
    "Your password on %s was reset by an administrator." : "Administrator je promijenio vašu zaporku na %s.",
    "Your password on %s was reset." : "Vaša zaporka na %s je resetirana.",
    "Password for %1$s changed on %2$s" : "Promijenjena je zaporka za %1$s na %2$s",
    "Password changed for %s" : "Promijenjena je zaporka za %s",
    "If you did not request this, please contact an administrator." : "Ako niste zatražili navedenu radnju, obratite se administratoru.",
    "Your email address on %s was changed." : "Promijenjena je vaša adresa e-pošte na %s.",
    "Your email address on %s was changed by an administrator." : "Administrator je promijenio vašu adresu e-pošte na %s.",
    "Email address for %1$s changed on %2$s" : "Promijenjena je adresa e-pošte za %1$s na %2$s",
    "Email address changed for %s" : "Promijenjena je adresa e-pošte za %s",
    "The new email address is %s" : "Nova adresa e-pošte je %s",
    "Your %s account was created" : "Stvoren je vaš račun %s",
    "Welcome aboard" : "Dobrodošli",
    "Welcome aboard %s" : "Dobrodošli u %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Dobrodošli u svoj račun %s, sada možete dodati, zaštititi i dijeliti svoje podatke.",
    "Your username is: %s" : "Vaše korisničko ime je: %s",
    "Set your password" : "Postavite zaporku",
    "Go to %s" : "Idi na %s",
    "Install Client" : "Instaliraj klijenta",
    "Logged in user must be a subadmin" : "Korisnik koji je prijavljen mora biti podadministrator",
    "Settings" : "Postavke",
    "Personal" : "Osobno",
    "Administration" : "Administracija",
    "Additional settings" : "Dodatne postavke",
    "Administration privileges" : "Ovlasti za administriranje",
    "Groupware" : "Groupware",
    "Overview" : "Pregled",
    "Basic settings" : "Osnovne postavke",
    "Sharing" : "Dijeljenje",
    "Availability" : "Raspoloživost",
    "Calendar" : "Kalendar",
    "Personal info" : "Osobne informacije",
    "Mobile & desktop" : "Mobilni uređaji i osobna računala",
    "Email server" : "Poslužitelj e-pošte",
    "Security & setup warnings" : "Upozorenja o sigurnosti i postavljanju",
    "Background jobs" : "Pozadinski zadaci",
    "Create" : "Stvori",
    "Change" : "Promijeni",
    "Delete" : "Izbriši",
    "Reshare" : "Dijeli ponovno",
    "Unlimited" : "Neograničeno",
    "Verifying" : "Provjeravanje",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čekanju je pozadinski zadatak za provjeravanje vjerodajnica SSL-a koje uvezu korisnici. Provjerite ponovno kasnije.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Prisutne su vjerodajnice SSL-a koje su uvezli korisnici i koje Nextcloud 21 ne upotrebljava. Mogu se uvesti putem naredbenog retka s pomoću naredbe „occ security:certificates:import”. U nastavku su prikazani njihovi putovi unutar podatkovnog direktorija.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Omogućen je stari format šifriranja na strani poslužitelja. Preporučujemo da ga onemogućite.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogućena je konfiguracija samo za čitanje. Time se sprječava postavljanje nekih konfiguracija putem web-sučelja. Nadalje, datoteku treba ručno prebaciti u način pisanja pri svakom ažuriranju.",
    "Nextcloud settings" : "Postavke Nextclouda",
    "Here you can decide which group can access certain sections of the administration settings." : "Ovdje možete odlučiti koja grupa može pristupiti određenim dijelovima administratorskih postavki.",
    "None" : "Nema",
    "Unable to modify setting" : "Nije moguće izmijeniti postavku",
    "Two-Factor Authentication" : "Dvofaktorska autentifikacija",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvofaktorska autentifikacija može se primijeniti na sve korisnike i određene grupe. Ako nisu konfigurirali davatelje usluge dvofaktorske autentifikacije, neće se moći prijaviti u sustav.",
    "Enforce two-factor authentication" : "Primijeni dvofaktorsku autentifikaciju",
    "Limit to groups" : "Ograniči na grupe",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Primjena dvofaktorske autentifikacije može se postaviti samo za određene grupe.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dvofaktorska autentifikacija primjenjuje se na sve članove sljedećih grupa.",
    "Enforced groups" : "Obuhvaćene grupe",
    "Two-factor authentication is not enforced for members of the following groups." : "Dvofaktorska autentifikacija ne primjenjuje se na članove sljedećih grupa.",
    "Excluded groups" : "Izuzete grupe",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Nakon odabira grupa koje će biti obuhvaćene/izuzete, primjenjuje se sljedeća logika za utvrđivanje je li 2FA omogućen za određenog korisnika: ako nije odabrana nijedna grupa, 2FA je omogućen za sve osim za članove izuzetih grupa. Ako su odabrane određene grupe, 2FA je omogućen samo za sve članove tih grupa. Ako je korisnik član odabrane i izuzete grupe, odabrana grupa ima prednost i 2FA se primjenjuje.",
    "Save changes" : "Spremi promjene",
    "All" : "Sve",
    "Limit app usage to groups" : "Ograničite primjenu aplikacije na grupe",
    "No results" : "Nema rezultata",
    "Update to {version}" : "Ažuriraj na {version}",
    "Remove" : "Ukloni",
    "Disable" : "Onemogući",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ovoj aplikaciji nije dodijeljena najmanja inačica Nextclouda. To će biti pogreška u budućnosti.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ovoj aplikaciji nije dodijeljena najveća inačica Nextclouda. To će biti pogreška u budućnosti.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aplikaciju nije moguće instalirati jer nisu ispunjene sljedeće ovisnosti:",
    "View in store" : "Pogledajte u trgovini",
    "Visit website" : "Posjeti web-mjesto",
    "Report a bug" : "Prijavi pogrešku",
    "Admin documentation" : "Dokumentacija za administratore",
    "Developer documentation" : "Dokumentacija za razvojne programere",
    "This app is supported via your current Nextcloud subscription." : "Aplikacija je podržana unutar vaše trenutne pretplate na Nextcloud.",
    "Supported" : "Podržano",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Istaknute aplikacije razvijaju članovi zajednice. One nude osnovnu funkcionalnost i spremne su za produkciju.",
    "Featured" : "Istaknuto",
    "Update to {update}" : "Ažuriraj na {update}",
    "Icon" : "Ikona",
    "Name" : "Naziv",
    "Version" : "Inačica",
    "Level" : "Razina",
    "Actions" : "Radnje",
    "Results from other categories" : "Rezultati iz drugih kategorija",
    "No apps found for your version" : "Nije pronađena nijedna aplikacija za vašu inačicu",
    "Disable all" : "Onemogući sve",
    "_%n app has an update available_::_%n apps have an update available_" : ["Dostupno je ažuriranje za %n aplikaciju","Dostupno je ažuriranje za %n aplikacije","Dostupno je ažuriranje za %n aplikacija"],
    "Marked for remote wipe" : "Označeno za udaljeno brisanje",
    "Device settings" : "Postavke uređaja",
    "Allow filesystem access" : "Omogući pristup datotečnom sustavu",
    "Rename" : "Preimenuj",
    "Revoke" : "Opozovi",
    "Wipe device" : "Izbriši sve s uređaja",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome za Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} aplikacija za iOS",
    "{productName} Android app" : "{productName} aplikacija za Android",
    "{productName} Talk for iOS" : "{productName} Talk za iOS",
    "{productName} Talk for Android" : "{productName} Talk za Android",
    "Sync client - {os}" : "Sinkroniziraj klijenta – {os}",
    "This session" : "Ova sesija",
    "Device" : "Uređaj",
    "Last activity" : "Posljednja aktivnost",
    "Devices & sessions" : "Uređaji i sesije",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, računalni i mobilni klijenti trenutno prijavljeni u vaš račun.",
    "Do you really want to wipe your data from this device?" : "Želite li zaista izbrisati podatke s ovog uređaja?",
    "Confirm wipe" : "Potvrdi brisanje",
    "Error while creating device token" : "Pogreška pri stvaranju tokena za uređaj",
    "Error while updating device token scope" : "Pogreška pri ažuriranju raspona tokena za uređaj",
    "Error while updating device token name" : "Pogreška pri ažuriranju naziva tokena za uređaja",
    "Error while deleting the token" : "Pogreška pri brisanju tokena",
    "Error while wiping the device with the token" : "Pogreška pri brisanju sadržaja uređaja tokenom",
    "App name" : "Naziv aplikacije",
    "Create new app password" : "Stvori novu zaporku za aplikaciju",
    "Use the credentials below to configure your app or device." : "Upotrijebite vjerodajnice navedene u nastavku za konfiguriranje aplikacije ili uređaja.",
    "For security reasons this password will only be shown once." : "Iz sigurnosnih razloga ta će se zaporka prikazati samo jednom.",
    "Username" : "Korisničko ime",
    "Password" : "Zaporka",
    "Done" : "Gotovo",
    "Show QR code for mobile apps" : "Prikaži QR kôd za mobilne aplikacije",
    "Copied!" : "Kopirano!",
    "Copy" : "Kopiraj",
    "Could not copy app password. Please copy it manually." : "Kopiranje zaporke aplikacije nije uspjelo. Kopirajte je ručno.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Koristite se sistemskim servisom cron za pozivanje datoteke cron.php svakih 5 minuta.",
    "Profile" : "Profil",
    "Enable" : "Omogući",
    "Server-side encryption" : "Šifriranje na poslužitelju",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifriranje na poslužitelju omogućuje šifriranje datoteka koje su otpremljene na ovaj poslužitelj. Ovaj postupak može narušiti performanse sustava pa ga omogućite samo ako je potrebno.",
    "Enable server-side encryption" : "Omogući šifriranje na poslužitelju",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ako je šifriranje na poslužitelju omogućeno, sve datoteke koje se od tog trenutka otpreme na poslužitelj bit će šifrirane u stanju mirovanja na poslužitelju. Kasnije možete onemogućiti šifriranje ako aktivni modul za šifriranje podržava tu funkciju i ispunjeni su svi preduvjeti (npr. postavljanje ključa za oporavak).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifriranje samo po sebi ne jamči sigurnost sustava. Pogledajte dokumentaciju za više informacija o načinu rada aplikacije za šifriranje i slučajevima korištenja.",
    "Be aware that encryption always increases the file size." : "Imajte na umu da šifriranje uvijek povećava veličinu datoteke.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Uvijek je dobra ideja redovito izrađivati sigurnosne kopije podataka; ako upotrebljavate šifriranje, obavezno sigurnosno kopirajte ključeve za šifriranje zajedno sa svojim podacima.",
    "This is the final warning: Do you really want to enable encryption?" : "Ovo je posljednje upozorenje: želite li zaista omogućiti šifriranje?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nije učitan modul za šifriranje, omogućite modul za šifriranje u izborniku aplikacije.",
    "Select default encryption module:" : "Odaberi zadani modul za šifriranje:",
    "Cancel" : "Odustani",
    "Confirm" : "Potvrdi",
    "Submit" : "Šalji",
    "Remove group" : "Ukloni grupu",
    "Current password" : "Trenutna zaporka",
    "New password" : "Nova zaporka",
    "Change password" : "Promijeni zaporku",
    "Picture provided by original account" : "Slika s izvornog računa",
    "Your biography" : "Vaša biografija",
    "Details" : "Pojedinosti",
    "You are a member of the following groups:" : "Član ste sljedećih grupa:",
    "Your full name" : "Vaše ime i prezime",
    "Email options" : "Mogućnosti e-pošte",
    "Primary email for password reset and notifications" : "Primarna e-pošta za resetiranje zaporke i primanje obavijesti",
    "Remove primary email" : "Ukloni primarnu adresu e-pošte",
    "Delete email" : "Izbriši adresu e-pošte",
    "Unset as primary email" : "Poništi primarnu adresu e-pošte",
    "This address is not confirmed" : "Ova adresa nije potvrđena",
    "Set as primary email" : "Postavi kao primarnu adresu e-pošte",
    "Additional email address {index}" : "Dodatne adrese e-pošte {index}",
    "Unable to delete primary email address" : "Nije moguće izbrisati primarnu adresu e-pošte",
    "Unable to update primary email address" : "Nije moguće ažurirati primarnu adresu e-pošte",
    "Unable to add additional email address" : "Nije moguće dodati dodatnu adresu e-pošte",
    "Unable to update additional email address" : "Nije moguće ažurirati dodatnu adresu e-pošte",
    "Unable to delete additional email address" : "Nije moguće izbrisati dodatnu adresu e-pošte",
    "No email address set" : "Nije postavljena adresa e-pošte",
    "Additional emails" : "Dodatne adrese e-pošte",
    "Your headline" : "Vaš naslov",
    "Help translate" : "Pomozite prevesti",
    "Unable to update language" : "Nije moguće ažurirati jezik",
    "No language set" : "Nije postavljen jezik",
    "Your organisation" : "Vaša organizacija",
    "Your phone number" : "Vaš broj telefona",
    "Edit your Profile visibility" : "Uredite vidljivost profila",
    "Enable Profile" : "Omogući profil",
    "Unable to update profile enabled state" : "Nije moguće ažurirati stanje omogućenog profila",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Na profilu se primjenjuje stroža postavka vidljivosti ili opsega. Na primjer, ako je vidljivost postavljena na „Prikaži svima”, a opseg je postavljen na „Privatno”, primjenjuje se „Privatno”.",
    "Unable to update visibility of {displayId}" : "Nije moguće ažurirati vidljivost za {displayId}",
    "Your role" : "Vaša uloga",
    "Add" : "Dodaj",
    "Default language" : "Zadani jezik",
    "Common languages" : "Česti jezici",
    "Other languages" : "Drugi jezici",
    "Password change is disabled because the master key is disabled" : "Onemogućeno je mijenjanje zaporke jer je onemogućen glavni ključ",
    "New user" : "Novi korisnik",
    "Display name" : "Ime za prikaz",
    "Email" : "E-pošta",
    "Quota" : "Kvota",
    "Language" : "Jezik",
    "Avatar" : "Avatar",
    "Group admin for" : "Administrator grupe za",
    "User backend" : "Korisnički pozadinski sustav",
    "Storage location" : "Mjesto pohrane",
    "Last login" : "Posljednja prijava",
    "You do not have permissions to see the details of this user" : "Nemate dopuštenja za prikaz pojedinosti ovog korisnika",
    "Add user to group" : "Dodaj korisnika u grupu",
    "Set user as admin for" : "Postavi korisnika kao administratora za",
    "Select user quota" : "Odaberi kvotu korisnika",
    "{size} used" : "Iskorišteno {size}",
    "Delete user" : "Izbriši korisnika",
    "Wipe all devices" : "Izbriši podatke sa svih uređaja",
    "Disable user" : "Onemogući korisnika",
    "Enable user" : "Omogući korisnika",
    "Resend welcome email" : "Ponovno pošalji poruku dobrodošlice",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "U slučaju gubitka uređaja ili napuštanja organizacije, može daljinski izbrisati Nextcloudove podatke sa svih uređaja kojima se koristi {userid}. Brisanje je moguće samo ako su uređaji povezani na internet.",
    "Remote wipe of devices" : "Daljinsko brisanje podataka s uređaja",
    "Wipe {userid}'s devices" : "Izbriši podatke sa svih uređaja koji pripadaju {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "U potpunosti izbriši račun koji pripada {userid}, uključujući sve osobne datoteke, aplikacije itd.",
    "Account deletion" : "Brisanje računa",
    "Delete {userid}'s account" : "Izbriši račun koji pripada {userid}",
    "Welcome mail sent!" : "Poslana poruka dobrodošlice!",
    "Toggle user actions menu" : "Uklj./isklj. izbornik s radnjama korisnika",
    "Edit" : "Uredi",
    "Show user backend" : "Prikaži korisnički pozadinski sustav",
    "Show storage path" : "Prikaži put pohrane",
    "Show last login" : "Prikaži posljednju prijavu",
    "Send email" : "Pošalji poruku e-pošte",
    "Default quota" : "Zadana kvota",
    "Select default quota" : "Odaberi zadanu kvotu",
    "Passwordless authentication requires a secure connection." : "Autentifikacija bez zaporke zahtijeva sigurnu vezu.",
    "Add WebAuthn device" : "Dodaj WebAuthn uređaj",
    "Please authorize your WebAuthn device." : "Autorizirajte svoj WebAuthn uređaj.",
    "Name your device" : "Dodijelite naziv svom uređaju",
    "Adding your device …" : "Dodavanje uređaja...",
    "Server error while trying to add WebAuthn device" : "Pogreška poslužitelja pri dodavanju WebAuthn uređaja",
    "Server error while trying to complete WebAuthn device registration" : "Pogreška poslužitelja tijekom dovršavanja registracije WebAuthn uređaja",
    "Unnamed device" : "Neimenovani uređaj",
    "Passwordless Authentication" : "Autentifikacija bez zaporke",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Omogućite korištenje autentifikacije bez zaporke na svom računu u skladu sa standardom FIDO2.",
    "No devices configured." : "Nema konfiguriranih uređaja.",
    "The following devices are configured for your account:" : "Sljedeći su uređaji konfigurirani za vaš račun:",
    "Your browser does not support WebAuthn." : "Vaš preglednik ne podržava WebAuthn.",
    "Your apps" : "Vaše aplikacije",
    "{license}-licensed" : "Licencirano prema {license}",
    "Changelog" : "Zapis promjena",
    "by {author}\n{license}" : "{autor}\n{licenca}",
    "Active users" : "Aktivni korisnici",
    "Admins" : "Administratori",
    "Disabled users" : "Onemogućeni korisnici",
    "Group name" : "Naziv grupe",
    "Not saved" : "Nije spremljeno",
    "Sending…" : "Slanje…",
    "Email sent" : "E-pošta je poslana",
    "Location" : "Lokacija",
    "Profile picture" : "Profilna slika",
    "About" : "Informacije",
    "Full name" : "Puno ime",
    "Additional email" : "Dodatna adresa e-pošte",
    "Headline" : "Naslov",
    "Organisation" : "Organizacija",
    "Phone number" : "Broj telefona",
    "Role" : "Uloga",
    "Twitter" : "Twitter",
    "Website" : "Web-mjesto",
    "Profile visibility" : "Vidljivost profila",
    "Locale" : "Lokacija",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nije dostupno jer je ovo svojstvo potrebno za osnovnu funkcionalnost, uključujući dijeljenje datoteka i pozivnice za kalendar",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nije dostupno jer nije dopušteno objavljivanje korisničkih podataka na poslužitelju pretraživanja, obratite se administratoru sustava ako imate pitanja",
    "Active apps" : "Aktivne aplikacije",
    "Disabled apps" : "Onemogućene aplikacije",
    "Updates" : "Ažuriranja",
    "App bundles" : "Paketi aplikacija",
    "Featured apps" : "Istaknute aplikacije",
    "Show to everyone" : "Prikaži svima",
    "Show to logged in users only" : "Prikaži samo prijavljenim korisnicima",
    "Hide" : "Sakrij",
    "Download and enable" : "Preuzmi i omogući",
    "The app will be downloaded from the App Store" : "Aplikacija će se preuzeti iz trgovine aplikacijama",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ova aplikacija nije označena kao kompatibilna s vašom inačicom Nextclouda. Ako odlučite nastaviti, moći ćete instalirati aplikaciju. Imajte na umu da aplikacija možda neće raditi kako očekujete.",
    "Never" : "Nikad",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacija je omogućena, ali je treba ažurirati. Za 5 sekundi bit ćete preusmjereni na stranicu za ažuriranje.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Pogreška: ova aplikacija ne može biti omogućena jer čini poslužitelj nestabilnim",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zaprimljeno je previše zahtjeva iz vaše mreže. Pokušajte kasnije ili se obratite administratoru ako se radi o pogrešci.",
    "Documentation" : "Dokumentacija",
    "Forum" : "Forum",
    "Login" : "Prijava",
    "SSL" : "SSL",
    "Open documentation" : "Otvori dokumentaciju",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Važno je postaviti ovaj poslužitelj kako biste mogli slati poruke e-pošte u vezi s resetiranjem zaporke i obavijesti.",
    "Send mode" : "Način slanja",
    "Encryption" : "Šifriranje",
    "Sendmail mode" : "Način slanja pošte",
    "From address" : "Adresa pošiljatelja",
    "Server address" : "Adresa poslužitelja",
    "Port" : "Port",
    "Authentication" : "Autentifikacija",
    "Authentication required" : "Potrebna autentifikacija",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "Korisničko ime za SMTP",
    "SMTP Password" : "SMTP zaporka",
    "Save" : "Spremi",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pravilna konfiguracija iznimno je važna za sigurnost i performanse vaše instance. Kako bismo vam pomogli pravilno konfigurirati sustav, provest ćemo neke automatske provjere. Za više informacija pogledajte navedenu dokumentaciju.",
    "All checks passed." : "Sve su provjere uspješno dovršene.",
    "There are some errors regarding your setup." : "Postoje neke pogreške u vezi s vašim postavom.",
    "There are some warnings regarding your setup." : "Postoje neka upozorenja u vezi s vašim postavom.",
    "Checking for system and security issues." : "Provjera sustava i sigurnosnih postavki.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Pažljivo pročitajte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">upute za instalaciju ↗</a> i potražite postoje li ikakve pogreške ili upozorenja u <a href=\"%2$s\">zapisima</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Provjerite sigurnost svojeg Nextclouda s pomoću <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">sigurnosnog skeniranja ↗</a>.",
    "You need to enable the File sharing App." : "Morate omogućiti aplikaciju za dijeljenje datoteka.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administrator možete detaljnije podešavati dijeljenja. Pogledajte odgovarajuću dokumentaciju za više informacija.",
    "Allow apps to use the Share API" : "Dopusti aplikacijama korištenje API-ja za dijeljenje",
    "Set default expiration date for shares" : "Postavi zadani datum isteka dijeljenja",
    "Expire after" : "Istek nakon",
    "day(s)" : "dan/dana",
    "Enforce expiration date" : "Primijeni datum isteka",
    "Set default expiration date for shares to other servers" : "Postavi zadani datum isteka dijeljenja na druge poslužitelje",
    "Allow users to share via link and emails" : "Dopusti korisnicima dijeljenje putem poveznice i e-pošte",
    "Allow public uploads" : "Dopusti javne otpreme",
    "Always ask for a password" : "Uvijek traži zaporku",
    "Enforce password protection" : "Nametni zaštitu zaporkom",
    "Set default expiration date" : "Postavi zadani datum isteka",
    "Exclude groups from creating link shares:" : "Izuzmite grupe iz stvaranja dijeljenja poveznice:",
    "Allow resharing" : "Dopusti ponovno dijeljenje",
    "Allow sharing with groups" : "Dopusti dijeljenje s grupama",
    "Restrict users to only share with users in their groups" : "Ograniči korisnike na dijeljenje samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Izuzmi grupe iz dijeljenja",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene sadržaje, ali ih neće moći pokrenuti.",
    "Allow username autocompletion to users based on phone number integration" : "Omogući korisnicima automatsko dovršavanje korisničkog imena na temelju integracije telefonskog broja",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ako je omogućeno automatsko dovršavanje „ista grupa” i „integracija telefonskog broja”, bilo koje od tih podudaranja dovoljno je za prikaz korisnika.",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Prikaži tekst izjave o odricanju od odgovornosti na stranici za otpremanje javnih poveznica (prikazuje se samo kad je popis datoteka skriven)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ovaj će tekst biti prikazan na stranici za otpremanje javnih poveznica kad je popis datoteka skriven.",
    "Default share permissions" : "Zadana dopuštenja za dijeljenje",
    "Reasons to use Nextcloud in your organization" : "Razlozi za uporabu Nextclouda u vašoj organizaciji",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{githubopen}Izvorni kôd{linkclose} je razvila {communityopen}Nextcloudova zajednica korisnika{linkclose} i licenciran je sukladno {Licenseopen}AGPL-u{linkclose}.",
    "Like our Facebook page" : "Pratite našu Facebook stranicu",
    "Follow us on Twitter" : "Pratite nas na Twitteru",
    "Follow us on Mastodon" : "Pratite nas na Mastodonu",
    "Check out our blog" : "Pogledajte naš blog",
    "Subscribe to our newsletter" : "Pretplatite se na naše obavijesti",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti.",
    "Use a second factor besides your password to increase security for your account." : "Koristite se i drugim faktorom pored zaporke kako biste povećali sigurnost svog računa.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ako se za povezivanje s Nextcloudom koristite aplikacijama treće strane, stvorite i konfigurirajte lozinku za svaku aplikaciju prije omogućavanja drugog faktora za provođenje autentifikacije.",
    "You created app password \"{token}\"" : "Stvorili ste zaporku aplikacije „{token}”",
    "Enable all" : "Omogući sve",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za izvršavanje navedenog postupka potrebno je proširenje PHP POSIX. Pogledajte {linkstart}dokumentaciju PHP-a{linkend} za više informacija.",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Izbrisat ćete grupu {group}. Korisnici NEĆE biti izbrisani.",
    "Please confirm the group removal " : "Potvrdite uklanjanje grupe ",
    "png or jpg, max. 20 MB" : "png ili jpg, maks. 20 MB",
    "Your email address" : "Vaša adresa e-pošte",
    "Add new password" : "Dodaj novu zaporku",
    "Add new email address" : "Dodaj novu adresu e-pošte",
    "Edit User" : "Uredi korisnika",
    "Will be autogenerated" : "Automatski će se generirati",
    "Add a new user" : "Dodaj novog korisnika",
    "No users in here" : "Ovdje nema korisnika",
    "Enter group name" : "Unesite naziv grupe",
    "Add group" : "Dodaj grupu",
    "Default quota:" : "Zadana kvota:",
    "Show Languages" : "Prikaži jezike",
    "Send email to new user" : "Pošalji poruku e-pošte novom korisniku",
    "Enable untested app" : "Omogući neprovjerenu aplikaciju",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Način autentifikacije",
    "Allow username autocompletion in share dialog" : "Dopusti automatsko dovršavanje korisničkog imena u dijaloškom okviru za dijeljenje",
    "Allow username autocompletion to users within the same groups" : "Dopusti automatsko dovršavanje korisničkog imena na korisnike iz istih grupa"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
